Welcome to Expetator's documentation
=====================================

.. toctree::
   :maxdepth: 4

   expetator
   expetator.benchmarks
   expetator.leverages
   expetator.monitors


.. include:: ../README.md
   :parser: myst_parser.sphinx_

